@@ -1,10 +1,10 @@
-from datetime import datetime, date
+from datetime import date, datetime
 from pathlib import Path
-from typing import Union, IO, AnyStr, Dict, List, Any, Callable, Tuple
+from typing import Any, Callable, Dict, IO, List, Tuple, Union
 
 from coinmetrics.constants import PagingFrom
 
-FilePathOrBuffer = Union[str, Path, IO[AnyStr]]
+FilePathOrBuffer = Union[str, Path, IO[str], IO[bytes], None]
 DataReturnType = Dict[str, Union[str, Dict[str, str], List[Dict[str, Any]]]]
 DataRetrievalFuncType = Callable[[str, Dict[str, Any]], DataReturnType]
 UrlParamTypes = Union[
